@@ -324,6 +324,7 @@ PCP_CALL extern int pmGetInDomArchive(pmInDom, int **, char ***);
  * Given context ID, return the host name associated with that context,
  * or the empty string if no name can be found
  */
+PCP_CALL extern int pmGetHostName(int, char *, int);
 PCP_CALL extern const char *pmGetContextHostName(int);
 PCP_CALL extern char *pmGetContextHostName_r(int, char *, int);
 
@@ -1136,9 +1137,15 @@ typedef struct {
     int labels;		/* Metric label metadata operations */
     int series;		/* Time series tracing */
     int	libweb;		/* Trace services from libpcp_web */
+    int	alloc;		/* Miscellaneous alloc/free operations */
+    int	services;	/* Services and daemons */
     int	appl3;		/* Application-specific flag 3 */
     int	appl4;		/* Application-specific flag 4 */
     int	appl5;		/* Application-specific flag 5 */
+    int access;		/* Access controls */
+    int qa;		/* QA (transient, developers only) */
+    int search;		/* Text search tracing */
+    int query;		/* libpcp_web query parsing and evaulation */
 } pmdebugoptions_t;
 
 PCP_DATA extern pmdebugoptions_t	pmDebugOptions;
